dnl @synopsis AC_PERL_MODULES_VERSION([MODULE VERSION], [ACTION-IF-TRUE], [ACTION-IF-FALSE])
dnl @summary Checks if the given list of 'Module Version' are avaiable
dnl 
dnl Checks to see if the list of 'Module Version' are avaiable in the system.
dnl If all the modules in the list are avaiable ACTION-IF-TRUE is executed.
dnl Case one module is not avaiable ACTION-IF-FALSE is executed and the macro
dnl execution is aborted.
dnl NOTE: Perl is needed.
dnl
dnl Example:
dnl
dnl   AC_PERL_MODULES_VERSION(CGI::Test 0.104 CGI::Ajax 0.694, ,
dnl      AC_MSG_ERROR(Need some Perl modules))
dnl
dnl @author Marco Gomes <mpglesi@gmail.com>
dnl @author Ruben Fonseca <fonseka@gmail.com>
dnl @version 2006-05-12
dnl @license AllPermissive

AC_DEFUN([AC_PERL_MODULES_VERSION],[dnl
ac_perl_list_modules="$1"
# Make sure we have perl
if test -z "$PERL"; then
AC_CHECK_PROG(PERL,perl,perl)
fi

# Check the number of arguments
args_num=`echo $ac_perl_list_modules | wc -w`
let "ckeck_args = $args_num % 2"
if test "$check_args" = "1" ; then
  AC_MSG_ERROR(syntax error)
else
  eval
fi

if test "x$PERL" != x; then
  ac_failed=0
  while test ${#ac_perl_list_modules} -gt 2 ; do
	module_name=`echo $ac_perl_list_modules | cut -d " " -f 1`
	module_version=`echo $ac_perl_list_modules | cut -d " " -f 2`
	ac_perl_list_modules=`echo $ac_perl_list_modules | cut -d " " -f 3-`
	AC_MSG_CHECKING(Perl module $module_name >= $module_version)

	$PERL "-M$module_name" -e exit > /dev/null 2>&1
	if test $? -ne 0; then
	  AC_MSG_RESULT(no);
	  ac_failed=1
	  ac_perl_list_modules=""
	else
	  version=`$PERL "-M$module_name" -e 'print $'"$module_name::VERSION" 2>&1`
	  $PERL -e 'exit(shift cmp shift)' "$version" "$module_version"
	  if test $? -eq 0 -o $? -eq 1 ; then
	    AC_MSG_RESULT([ok ($version)]);
	  else
	    AC_MSG_RESULT(no)
	    ac_failed=1
	    ac_perl_list_modules=""
	  fi
	fi;
  done

  if test "$ac_failed" = 0; then
    :
    $2
  else
    :
    $3
  fi
else
  AC_MSG_ERROR(could not find Perl 5 interpreter)
fi])dnl




##########
##########
##########

AC_DEFUN([AX_BERKELEY_DB],
[
  old_LIBS="$LIBS"
  old_CFLAGS="$CFLAGS"

  dbprefixes="/usr/local /opt/local"

  AC_ARG_WITH([db],
    [AS_HELP_STRING([--with-db-prefix],
      [Specify prefix for installed Berkeley DB])])

  AS_IF([test "x$with_db_prefix" != x],
        [dbprefixes="$with_db_prefix"])

  minversion=ifelse([$1], ,,$1)

  DB_HEADER=""
  DB_LIBS=""
  DB_CFLAGS=""

  if test -z $minversion ; then
      minvermajor=0
      minverminor=0
      minverpatch=0
      AC_MSG_CHECKING([for Berkeley DB])
  else
      minvermajor=`echo $minversion | cut -d. -f1`
      minverminor=`echo $minversion | cut -d. -f2`
      minverpatch=`echo $minversion | cut -d. -f3`
      minvermajor=${minvermajor:-0}
      minverminor=${minverminor:-0}
      minverpatch=${minverpatch:-0}
      AC_MSG_CHECKING([for Berkeley DB >= $minversion])
  fi

  for version in "" 5.0 4.9 4.8 4.7 4.6 4.5 4.4 4.3 4.2 4.1 4.0 3.6 3.5 3.4 3.3 3.2 3.1 ; do
     for db_prefix in $dbprefixes; do

	    if test -z $version ; then
	        db_lib="-ldb"
	        try_headers="db.h"
			try_libs="/"
	    else
	        db_lib="-ldb-$version"
	        try_headers="db$version/db.h db`echo $version | sed -e 's,\..*,,g'`/db.h db`echo $version | sed -e 's,\.,,g'`/db.h"
			try_libs="/db$version /db`echo $version | sed -e 's,\..*,,g'` /db`echo $version | sed -e 's,\.,,g'`"
	    fi

		for db_libaff in $try_libs; do
			
			LIBS="$old_LIBS -L$db_prefix/lib$db_libaff $db_lib"
			CFLAGS="$old_CFLAGS -I$db_prefix/include"
			
		    for db_hdr in $try_headers ; do
		        if test -z $DB_HEADER ; then
		            AC_LINK_IFELSE(
		                [AC_LANG_PROGRAM(
		                    [
		                        #include <${db_hdr}>
		                    ],
		                    [
		                        #if !((DB_VERSION_MAJOR > (${minvermajor}) || \
		                              (DB_VERSION_MAJOR == (${minvermajor}) && \
		                                    DB_VERSION_MINOR > (${minverminor})) || \
		                              (DB_VERSION_MAJOR == (${minvermajor}) && \
		                                    DB_VERSION_MINOR == (${minverminor}) && \
		                                    DB_VERSION_PATCH >= (${minverpatch}))))
		                            #error "too old version"
		                        #endif

		                        DB *db;
		                        db_create(&db, NULL, 0);
		                    ])],
		                [
		                    AC_MSG_RESULT([yes])
		                    printf "  - Berkeley BD header file: $db_hdr\n"
				    printf "  - Berkeley BD library flags: $db_lib\n"
                                    printf "  - Berkeley BD installation prefix: $db_prefix\n"

		                    DB_HEADER="$db_hdr"
		                    DB_LIBS="-L$db_prefix/lib/$db_libaff $db_lib"
							DB_CFLAGS="-I$db_prefix/include"
		                ])
		        fi
		    done
		done
  	 done
  done

  LIBS="$old_LIBS"
  CFLAGS="$old_CFLAGS"

  if test -z $DB_HEADER ; then
    AC_DEFINE([DB_HEADER], [], [DB Header file])
    AC_MSG_RESULT([not found])
    ifelse([$3], , :, [$3])
  else
    AC_DEFINE_UNQUOTED(DB_HEADER, ["$DB_HEADER"])
    AC_SUBST(DB_LIBS)
    AC_SUBST(DB_CFLAGS)
    ifelse([$2], , :, [$2])
  fi
])

